@@ -11,6 +11,8 @@ from easy_pysy.plugins.loop import loop, Loop, get_loop
 from easy_pysy.utils.common import uuid, IntSequence
 from easy_pysy.utils.decorators import require
 from easy_pysy.utils.decorators import retry
-from easy_pysy.utils.functional import magic, bind, bind_all, EzList, EzDict
+from easy_pysy.utils.functional.function import bind, bind_all
+from easy_pysy.utils.functional.iterable import List
+from easy_pysy.utils.functional.dictionary import Dict
 from easy_pysy.utils.generators import tri_wave, float_range
 from easy_pysy.utils.markdown import read_md_table
